#
# spec file for package opencsg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opencsg
Version:        1.6.0
Release:        2.5
Summary:        Constructive Solid Geometry rendering library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.opencsg.org/
Source:         https://www.opencsg.org/OpenCSG-%{version}.tar.gz
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libXmu-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtbase-devel

%description
OpenCSG is a library that does image-based Constructive Solid
Geometry rendering using OpenGL.

%package -n libopencsg1
Summary:        Constructive Solid Geometry rendering library
Group:          System/Libraries

%description -n libopencsg1
OpenCSG is a library that does image-based Constructive Solid
Geometry rendering using OpenGL. CSG denotes an approach to model 3D
shapes by applying operations such as union, intersection or
subtraction to so-called primtives, the latter of which are solid
(i.e. have a clearly defined interior and exterior).

%package doc
Summary:        Documents package for opencsg
BuildArch:      noarch

%description doc
This package contains the documentation for opencsg.

%package devel
Summary:        Development files for opencsg, a CSG rendering library
Group:          Development/Libraries/C and C++
Requires:       freeglut-devel
Requires:       glew-devel
Requires:       libopencsg1 = %{version}

%description devel
OpenCSG is a library that does image-based Constructive Solid
Geometry rendering using OpenGL.

This subpackage contains libraries and header files for developing
applications that want to make use of opencsg.

%prep
%setup -q -n OpenCSG-%{version}
# use system glew
rm -rf glew

%build
# do not build glew and examples
cd src
# rpath is evil
sed -i 's@-Wl,-rpath,\.\./lib@@' Makefile
%qmake5
%make_build

%install
mkdir -p %{buildroot}%{_prefix}
mv include %{buildroot}%{_includedir}
mv lib %{buildroot}%{_libdir}

%post -n libopencsg1 -p /sbin/ldconfig
%postun -n libopencsg1 -p /sbin/ldconfig

%files -n libopencsg1
%license copying.txt doc/license/gpl-3.0.txt doc/license/gpl-2.0.txt
%doc changelog.txt
%{_libdir}/libopencsg.so.1*

%files devel
%{_includedir}/*
%{_libdir}/libopencsg.so

%files doc
%doc doc/*

%changelog
* Mon Oct  9 2023 Paolo Stivanin <info@paolostivanin.com>
- Remove glew-devel dep since the project is now using GLAD.
* Thu Oct  5 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 1.6.0:
  * Glad is now used instead of GLEW for initialization of OpenGL
    function pointers and extensions.
* Sun Oct  2 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
    GCC 11/12 compile fixes
    Release 1.5.0 (license changed from GPLv2 to GPLv2 or newer)
    Resolved a couple of 64-bit warnings while testing Visual Studio 2019
* Fri Apr 13 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.4.2
- Drop individual HTML files from %%doc section
- Add doc folder from source to %%doc section
* Wed May 10 2017 jengelh@inai.de
- Compact and diversify package descriptions.
* Tue Jul  8 2014 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-linking-exception
  license allows GPL components to be linked with certain other components
* Fri Dec 13 2013 bugs@vdm-design.de
- update spec file for openSUSE 13.1 (libXmu-devel added as BuildRequires)
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 1.3.2
* Wed Oct 13 2010 prusnak@opensuse.org
- created package (1.3.1)
